==> eslint-plugin-devops-0.0.1-0.tgz: package/tests/lib/rules/filename-lower-case.js <==
/**
 * @fileoverview js,ts,vue名称需要以中划线分隔全小写字母数字命名
 * @author fwz
 */
"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const rule = require("../../../lib/rules/filename-lower-case"),
  RuleTester = require("eslint").RuleTester;

const config = {
  env: {
    browser: true,
    es6: true,
    mocha: true, // add mocha as true to your ".eslintrc. *" file
  },
  parser: require.resolve("vue-eslint-parser"),
  parserOptions: {
    ecmaVersion: 6,
    sourceType: "module",
    ecmaFeatures: {
      jsx: true,
    },
  },
};

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

const ruleTester = new RuleTester(config);
ruleTester.run("filename-lower-case", rule, {
  valid: [
    {
      filename: "./a-input.vue",
      code: `<template>
        <h1>{{ msg }}</h1>
        <input v-model="msg">
      </template>`,
    },
  ],

  invalid: [
    {
      filename: "./vue/aInput.vue",
      code: `<script setup>
      import { ref } from 'vue'
      
      const msg = ref('Hello World!')
      </script>
      
      <template>
        <h1>{{ msg }}</h1>
        <input v-model="msg">
      </template>`,
      errors: [
        {
          message: '文件名："aInput"多单词必须为全小写中划线分隔命名',
        },
      ],
    },
    {
      filename: "./InputName.vue",
      code: `<template>
        <h1>{{ msg }}</h1>
        <input v-model="msg">
      </template>`,
      errors: [
        {
          message: '文件名："InputName"多单词必须为全小写中划线分隔命名',
        },
      ],
    },
  ],
});

==> eslint-plugin-devops-0.0.1-1.tgz: package/tests/lib/rules/filename-lower-case.js <==
/**
 * @fileoverview js,ts,vue名称需要以中划线分隔全小写字母数字命名
 * @author fwz
 */
"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const rule = require("../../../lib/rules/filename-lower-case"),
  RuleTester = require("eslint").RuleTester;

const config = {
  env: {
    browser: true,
    es6: true,
    mocha: true, // add mocha as true to your ".eslintrc. *" file
  },
  parser: require.resolve("vue-eslint-parser"),
  parserOptions: {
    ecmaVersion: 6,
    sourceType: "module",
    ecmaFeatures: {
      jsx: true,
    },
  },
};

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

const ruleTester = new RuleTester(config);
ruleTester.run("filename-lower-case", rule, {
  valid: [
    {
      filename: "./a-input.vue",
      code: `<template>
        <h1>{{ msg }}</h1>
        <input v-model="msg">
      </template>`,
    },
  ],

  invalid: [
    {
      filename: "./vue/aInput.vue",
      code: `<script setup>
      import { ref } from 'vue'
      
      const msg = ref('Hello World!')
      </script>
      
      <template>
        <h1>{{ msg }}</h1>
        <input v-model="msg">
      </template>`,
      errors: [
        {
          message: '文件名："./vue/aInput.vue"多单词必须为全小写中划线分隔命名',
        },
      ],
    },
    {
      filename: "./InputName.vue",
      code: `<template>
        <h1>{{ msg }}</h1>
        <input v-model="msg">
      </template>`,
      errors: [
        {
          message: '文件名："./InputName.vue"多单词必须为全小写中划线分隔命名',
        },
      ],
    },
  ],
});
